pub struct TextStrWithLang<'a, 'b>(pub &'b [(LanguageIdentifier, &'a str)]);Expand description
A text string with a natural language specified.
This is written as a string containing either bare ASCII (if possible) or a byte order mark followed by UTF-16-BE bytes. Both forms are interspersed by the requisite ASCII language escape sequences.
For a text string with an undefined natural language, see TextStr.
Tuple Fields
0: &'b [(LanguageIdentifier, &'a str)]Trait Implementations
Sourceimpl<'a, 'b> Clone for TextStrWithLang<'a, 'b>
impl<'a, 'b> Clone for TextStrWithLang<'a, 'b>
Sourcefn clone(&self) -> TextStrWithLang<'a, 'b>
fn clone(&self) -> TextStrWithLang<'a, 'b>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, 'b> Debug for TextStrWithLang<'a, 'b>
impl<'a, 'b> Debug for TextStrWithLang<'a, 'b>
Sourceimpl<'a, 'b> Hash for TextStrWithLang<'a, 'b>
impl<'a, 'b> Hash for TextStrWithLang<'a, 'b>
Sourceimpl<'a, 'b> Ord for TextStrWithLang<'a, 'b>
impl<'a, 'b> Ord for TextStrWithLang<'a, 'b>
Sourcefn cmp(&self, other: &TextStrWithLang<'a, 'b>) -> Ordering
fn cmp(&self, other: &TextStrWithLang<'a, 'b>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<'a, 'b> PartialEq for TextStrWithLang<'a, 'b>
impl<'a, 'b> PartialEq for TextStrWithLang<'a, 'b>
Sourceimpl<'a, 'b> PartialOrd for TextStrWithLang<'a, 'b>
impl<'a, 'b> PartialOrd for TextStrWithLang<'a, 'b>
Sourceimpl<'a, 'b> Primitive for TextStrWithLang<'a, 'b>
impl<'a, 'b> Primitive for TextStrWithLang<'a, 'b>
impl<'a, 'b> Copy for TextStrWithLang<'a, 'b>
impl<'a, 'b> Eq for TextStrWithLang<'a, 'b>
impl<'a, 'b> StructuralPartialEq for TextStrWithLang<'a, 'b>
impl<'a, 'b> TextStrLike for TextStrWithLang<'a, 'b>