TextStrLike

Trait TextStrLike 

pub trait TextStrLike: Primitive { }
A trait for types that can be used everywhere a text string is expected. This includes both TextStr and TextStrWithLang.

Methods that accept an implementor of this trait expect strings in natural language for which a language specification makes sense, often for use in the UI or with AT.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a> TextStrLike for TextStr<'a>

Source

impl<'a, 'b> TextStrLike for TextStrWithLang<'a, 'b>