AttributeOwner

Enum AttributeOwner 

pub enum AttributeOwner {
Show 19 variants Layout, List, PrintField, Table, Artifact, Xml, Html3_2, Html4, Html5, Oeb, Rtf1_05, Css1, Css2, Css3, Rdfa1_1, Aria1_1, FENote, NSO, User,
}
Owner of the attribute dictionary.

Variants



Layout

General layout attributes.



List

List attributes.



PrintField

Attributes governing the print out behavior of form fields. PDF 1.7+.



Table

Table attributes.



Artifact

Attributes covering artifacts. PDF 2.0+.



Xml

Hints for conversion to XML 1.0.



Html3_2

Hints for conversion to HTML 3.2.



Html4

Hints for conversion to HTML 4.01.



Html5

Hints for conversion to HTML 5.



Oeb

Hints for conversion to OEB 1.0.



Rtf1_05

Hints for conversion to RTF 1.05.



Css1

Hints for conversion to CSS 1.



Css2

Hints for conversion to CSS 2.



Css3

Hints for conversion to CSS 3. PDF 2.0+.



Rdfa1_1

Hints for converting to a format expressed in RDFa 1.1. PDF 2.0+.



Aria1_1

ARIA 1.1 accessibility attributes for assistive technology. PDF 2.0+.



FENote

Attribute governing the interpretation of FENote elements. PDF/UA-2.



NSO

The attribute owner is a namespace. PDF 2.0+.



User

User-defined attributes. Requires to set the /UserProperties attribute of the MarkInfo dictionary to true. PDF 1.6+