Enum pdf_writer::types::FieldState
source · pub enum FieldState {
Unchecked,
Checked,
Neutral,
}Expand description
Whether a check box or radio button is checked.
Variants
Unchecked
The check box or radio button is unchecked.
Checked
The check box or radio button is checked.
Neutral
The check box or radio button is in a quantum superstate.