Enum pdf_writer::types::OverprintMode
source · pub enum OverprintMode {
OverrideAllColorants,
IgnoreZeroChannel,
}Expand description
How to behave when overprinting for colorants with the value zero.
Variants
OverrideAllColorants
An overprint operation will always discard the underlying color, even if one of the colorants is zero.
IgnoreZeroChannel
An overprint operation will only discard the underlying colorant component (e.g. cyan in CMYK) if the new corresponding colorant is non-zero.