Enum pdf_writer::types::Placement
source · pub enum Placement {
Block,
Inline,
Before,
Start,
End,
}Expand description
Placement of an element.
Variants
Block
Stacked in the block order.
Inline
Stacked in the inline order.
Before
Before edge coincides with that of reference area, touching the edge of the previous block.
Start
Start edge coincides with that of reference area, aligned on the non-stacking axis of the reference area.
End
End edge coincides with that of reference area, aligned on the non-stacking axis of the reference area.