TextPosition

Enum TextPosition 

pub enum TextPosition {
    CaptionOnly = 0,
    IconOnly = 1,
    Below = 2,
    Above = 3,
    Right = 4,
    Left = 5,
    Overlaid = 6,
}
The position the text of the widget annotation’s caption relative to its icon.

Variants



CaptionOnly = 0

Hide icon, show only caption.



IconOnly = 1

Hide caption, show only icon.



Below = 2

The caption should be placed below the icon.



Above = 3

The caption should be placed above the icon.



Right = 4

The caption should be placed to the right of the icon.



Left = 5

The caption should be placed to the left of the icon.



Overlaid = 6

The caption should be placed overlaid directly on the icon.