TransitionStyle

Enum TransitionStyle 

pub enum TransitionStyle {
    Split,
    Blinds,
    Box,
    Wipe,
    Dissolve,
    Glitter,
    R,
    Fly,
    Push,
    Cover,
    Uncover,
    Fade,
}
A kind of page transition.

Variants



Split

Split the slide down the middle.



Blinds

Multiple lines roll up the slide.



Box

The new slide is revealed in a growing box.



Wipe

Single line that sweeps across the slide.



Dissolve

Slide dissolves gradually.



Glitter

Like dissolve, but starts on one side.



R

No effect.



Fly

Changes are flown in. PDF 1.5+.



Push

Old page slides out, new page slides in. PDF 1.5+.



Cover

New page slides in to cover the old one. PDF 1.5+.



Uncover

Old page slides out to uncover the new one. PDF 1.5+.



Fade

A cross-fade. PDF 1.5+.