Struct pdf_writer::types::AnnotationFlags
source · pub struct AnnotationFlags { /* private fields */ }Expand description
Bitflags describing various characteristics of annotations.
Implementations
sourceimpl AnnotationFlags
impl AnnotationFlags
sourcepub const INVISIBLE: Self = _
pub const INVISIBLE: Self = _
This will hide the annotation if the viewer does not recognize its subtype. Otherwise, it will be rendered as specified in its appearance stream.
sourcepub const HIDDEN: Self = _
pub const HIDDEN: Self = _
This hides the annotation from view and disallows interaction. PDF 1.2+.
sourcepub const PRINT: Self = _
pub const PRINT: Self = _
Print the annotation. If not set, it will be always hidden on print. PDF 1.2+.
sourcepub const NO_ZOOM: Self = _
pub const NO_ZOOM: Self = _
Do not zoom the annotation appearance if the document is zoomed in. PDF 1.3+.
sourcepub const NO_ROTATE: Self = _
pub const NO_ROTATE: Self = _
Do not rotate the annotation appearance if the document is zoomed in. PDF 1.3+.
sourcepub const NO_VIEW: Self = _
pub const NO_VIEW: Self = _
Do not view the annotation on screen. It may still show on print. PDF 1.3+.
sourcepub const LOCKED: Self = _
pub const LOCKED: Self = _
Do not allow the user to delete or reposition the annotation. Contents may still be changed. PDF 1.4+.
sourcepub const TOGGLE_NO_VIEW: Self = _
pub const TOGGLE_NO_VIEW: Self = _
Invert the interpretation of the no_view flag for certain events.
PDF 1.5+.
sourcepub const LOCKED_CONTENTS: Self = _
pub const LOCKED_CONTENTS: Self = _
Do not allow content changes. PDF 1.7+.
sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> Self
pub const unsafe fn from_bits_unchecked(bits: u32) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.