pub struct ChoiceOptions<'a> { /* private fields */ }Expand description
Writer for a choice options array.
This struct is created by Field::choice_options.
Implementations
Sourceimpl ChoiceOptions<'_>
impl ChoiceOptions<'_>
Sourcepub fn option(&mut self, value: impl TextStrLike) -> &mut Self
pub fn option(&mut self, value: impl TextStrLike) -> &mut Self
Add an option with the given value.
Sourcepub fn options(
&mut self,
values: impl IntoIterator<Item = impl TextStrLike>,
) -> &mut Self
pub fn options( &mut self, values: impl IntoIterator<Item = impl TextStrLike>, ) -> &mut Self
Add options with the given values.
Sourcepub fn export(
&mut self,
value: impl TextStrLike,
export_value: TextStr<'_>,
) -> &mut Self
pub fn export( &mut self, value: impl TextStrLike, export_value: TextStr<'_>, ) -> &mut Self
Add an option with the given value and export value.
Sourcepub fn exports<'b>(
&mut self,
values: impl IntoIterator<Item = (impl TextStrLike, TextStr<'b>)>,
) -> &mut Self
pub fn exports<'b>( &mut self, values: impl IntoIterator<Item = (impl TextStrLike, TextStr<'b>)>, ) -> &mut Self
Add options with the given pairs of value and export value.
Methods from Deref<Target = Array<'a>>
Sourcepub fn item<T: Primitive>(&mut self, value: T) -> &mut Self
pub fn item<T: Primitive>(&mut self, value: T) -> &mut Self
Write an item with a primitive value.
This is a shorthand for array.push().primitive(value).
Sourcepub fn items<T: Primitive>(
&mut self,
values: impl IntoIterator<Item = T>,
) -> &mut Self
pub fn items<T: Primitive>( &mut self, values: impl IntoIterator<Item = T>, ) -> &mut Self
Write a sequence of items with primitive values.