pub struct Sides<T> {
pub before: T,
pub after: T,
pub start: T,
pub end: T,
}Expand description
A value that applies to the four sides of a rectangular container.
Fields
before: TThe value before the rectangle, in the block progression direction. In the LTR writing mode, this is the top side.
after: TThe value after the rectangle, in the block progression direction. In the LTR writing mode, this is the bottom side.
start: TThe value at the inline start edge of the rectangle. In the LTR writing mode, this is the left side.
end: TThe value at the inline end edge of the rectangle. In the LTR writing mode, this is the right side.
Implementations
Sourceimpl<T> Sides<T>
impl<T> Sides<T>
Sourcepub fn new(before: T, after: T, start: T, end: T) -> Self
pub fn new(before: T, after: T, start: T, end: T) -> Self
Create a new Sides struct with the given values for each side.
Sourcepub fn from_array(array: [T; 4]) -> Self
pub fn from_array(array: [T; 4]) -> Self
Create a new Sides struct with an array ordered as [before, after, start, end], just like in the PDF specification.