pub struct ArtifactAttributes<'a> { /* private fields */ }Expand description
Writer for a artifact attributes dictionary. PDF 2.0+
This struct is created by Attributes::artifact.
Implementations
Sourceimpl<'a> ArtifactAttributes<'a>
impl<'a> ArtifactAttributes<'a>
Sourcepub fn artifact_type(&mut self, artifact_type: ArtifactType) -> &mut Self
pub fn artifact_type(&mut self, artifact_type: ArtifactType) -> &mut Self
Write the /Type attribute to set the type of artifact.
Sourcepub fn bbox(&mut self, bbox: Rect) -> &mut Self
pub fn bbox(&mut self, bbox: Rect) -> &mut Self
Write the /BBox attribute to set the bounding box of the artifact.
Sourcepub fn subtype(&mut self, subtype: ArtifactSubtype<'_>) -> &mut Self
pub fn subtype(&mut self, subtype: ArtifactSubtype<'_>) -> &mut Self
Write the /Subtype attribute to set the subtype of pagination or
inline artifacts.
Methods from Deref<Target = Dict<'a>>
Sourcepub fn insert(&mut self, key: Name<'_>) -> Obj<'_>
pub fn insert(&mut self, key: Name<'_>) -> Obj<'_>
Start writing a pair with an arbitrary value.
Sourcepub fn pair<T: Primitive>(&mut self, key: Name<'_>, value: T) -> &mut Self
pub fn pair<T: Primitive>(&mut self, key: Name<'_>, value: T) -> &mut Self
Write a pair with a primitive value.
This is a shorthand for dict.insert(key).primitive(value).
Sourcepub fn pairs<'n, T: Primitive>(
&mut self,
pairs: impl IntoIterator<Item = (Name<'n>, T)>,
) -> &mut Self
pub fn pairs<'n, T: Primitive>( &mut self, pairs: impl IntoIterator<Item = (Name<'n>, T)>, ) -> &mut Self
Write a sequence of pairs with primitive values.