pub struct ListAttributes<'a> { /* private fields */ }Expand description
Writer for an list attributes dictionary. PDF 1.4+
This struct is created by Attributes::list.
Implementations
Sourceimpl<'a> ListAttributes<'a>
impl<'a> ListAttributes<'a>
Sourcepub fn list_numbering(&mut self, numbering: ListNumbering) -> &mut Self
pub fn list_numbering(&mut self, numbering: ListNumbering) -> &mut Self
Write the /ListNumbering attribute.
Sourcepub fn continued_list(&mut self, continued: bool) -> &mut Self
pub fn continued_list(&mut self, continued: bool) -> &mut Self
Write the /ContinuedList attribute. PDF 2.0+.
Setting this to true indicates that the list continues from the
previous list, or from the list indicated by the /ContinuedFrom
attribute.
Sourcepub fn continued_from(&mut self, id: Str<'_>) -> &mut Self
pub fn continued_from(&mut self, id: Str<'_>) -> &mut Self
Write the /ContinuedFrom attribute. PDF 2.0+.
Also see ListAttributes::continued_list.
Methods from Deref<Target = Dict<'a>>
Sourcepub fn insert(&mut self, key: Name<'_>) -> Obj<'_>
pub fn insert(&mut self, key: Name<'_>) -> Obj<'_>
Start writing a pair with an arbitrary value.
Sourcepub fn pair<T: Primitive>(&mut self, key: Name<'_>, value: T) -> &mut Self
pub fn pair<T: Primitive>(&mut self, key: Name<'_>, value: T) -> &mut Self
Write a pair with a primitive value.
This is a shorthand for dict.insert(key).primitive(value).
Sourcepub fn pairs<'n, T: Primitive>(
&mut self,
pairs: impl IntoIterator<Item = (Name<'n>, T)>,
) -> &mut Self
pub fn pairs<'n, T: Primitive>( &mut self, pairs: impl IntoIterator<Item = (Name<'n>, T)>, ) -> &mut Self
Write a sequence of pairs with primitive values.