pub struct OutputIntent<'a> { /* private fields */ }Expand description
Writer for an output intent dictionary. PDF 1.4+.
This describes the output conditions under which the document may be rendered. Encouraged by PDF/A.
Implementations
Sourceimpl OutputIntent<'_>
impl OutputIntent<'_>
Sourcepub fn subtype(&mut self, subtype: OutputIntentSubtype<'_>) -> &mut Self
pub fn subtype(&mut self, subtype: OutputIntentSubtype<'_>) -> &mut Self
Write the /S attribute. Required.
Sourcepub fn output_condition(&mut self, condition: impl TextStrLike) -> &mut Self
pub fn output_condition(&mut self, condition: impl TextStrLike) -> &mut Self
Write the /OutputCondition attribute.
A human-readable description of the output condition.
Sourcepub fn output_condition_identifier(
&mut self,
identifier: impl TextStrLike,
) -> &mut Self
pub fn output_condition_identifier( &mut self, identifier: impl TextStrLike, ) -> &mut Self
Write the /OutputConditionIdentifier attribute.
A well-known identifier for the output condition.
Sourcepub fn registry_name(&mut self, name: TextStr<'_>) -> &mut Self
pub fn registry_name(&mut self, name: TextStr<'_>) -> &mut Self
Write the /RegistryName attribute.
The URI of the registry that contains the output condition.
Sourcepub fn info(&mut self, info: impl TextStrLike) -> &mut Self
pub fn info(&mut self, info: impl TextStrLike) -> &mut Self
Write the /Info attribute.
A human-readable string with additional info about the intended output device.
Sourcepub fn dest_output_profile(&mut self, profile: Ref) -> &mut Self
pub fn dest_output_profile(&mut self, profile: Ref) -> &mut Self
Write the /DestOutputProfile attribute.
Required if /OutputConditionIdentifier does not contain a well-known
identifier for the output condition.
Must reference an ICC profile stream.
Required for PDF/A. The profile must have the prtr or mntr tag.