Struct pdf_writer::writers::SampledFunction
source · pub struct SampledFunction<'a> { /* private fields */ }Expand description
Writer for a sampled function stream. PDF 1.2+.
This struct is created by Chunk::sampled_function.
Implementations
sourceimpl<'a> SampledFunction<'a>
impl<'a> SampledFunction<'a>
sourcepub fn domain(&mut self, domain: impl IntoIterator<Item = f32>) -> &mut Self
pub fn domain(&mut self, domain: impl IntoIterator<Item = f32>) -> &mut Self
Write the /Domain attribute to set where the function is defined.
Required.
sourcepub fn range(&mut self, range: impl IntoIterator<Item = f32>) -> &mut Self
pub fn range(&mut self, range: impl IntoIterator<Item = f32>) -> &mut Self
Write the /Range attribute.
Required for sampled and PostScript functions.
sourcepub fn size(&mut self, size: impl IntoIterator<Item = i32>) -> &mut Self
pub fn size(&mut self, size: impl IntoIterator<Item = i32>) -> &mut Self
Write the /Size attribute.
Sets the number of input samples per dimension. Required.
sourcepub fn bits_per_sample(&mut self, bits: i32) -> &mut Self
pub fn bits_per_sample(&mut self, bits: i32) -> &mut Self
Write the /BitsPerSample attribute.
Sets the number of bits per input sample. Required.
sourcepub fn order(&mut self, order: InterpolationOrder) -> &mut Self
pub fn order(&mut self, order: InterpolationOrder) -> &mut Self
Write the /Order attribute.
Choose the implementation kind.
sourcepub fn encode(&mut self, encode: impl IntoIterator<Item = f32>) -> &mut Self
pub fn encode(&mut self, encode: impl IntoIterator<Item = f32>) -> &mut Self
Write the /Encode attribute.
For each sample, define how the input is mapped to the domain range.
sourcepub fn decode(&mut self, decode: impl IntoIterator<Item = f32>) -> &mut Self
pub fn decode(&mut self, decode: impl IntoIterator<Item = f32>) -> &mut Self
Write the /Decode attribute.
For each sample, define how the output is mapped to the output range.
Methods from Deref<Target = Stream<'a>>
Methods from Deref<Target = Dict<'a>>
sourcepub fn insert(&mut self, key: Name<'_>) -> Obj<'_>
pub fn insert(&mut self, key: Name<'_>) -> Obj<'_>
Start writing a pair with an arbitrary value.