pub struct TableAttributes<'a> { /* private fields */ }Expand description
Writer for a table attributes dictionary. PDF 1.4+
This struct is created by Attributes::table.
Implementations
Sourceimpl<'a> TableAttributes<'a>
impl<'a> TableAttributes<'a>
Sourcepub fn row_span(&mut self, row_span: i32) -> &mut Self
pub fn row_span(&mut self, row_span: i32) -> &mut Self
Write the /RowSpan attribute to set the number of rows that shall be
spanned by this cell.
Sourcepub fn col_span(&mut self, col_span: i32) -> &mut Self
pub fn col_span(&mut self, col_span: i32) -> &mut Self
Write the /ColSpan attribute to set the number of columns that shall
be spanned by this cell.
Sourcepub fn headers(&mut self) -> TypedArray<'_, Str<'_>>
pub fn headers(&mut self) -> TypedArray<'_, Str<'_>>
Write the /Headers attribute to refer to the header cells of the
table. PDF 1.6+.
Sourcepub fn scope(&mut self, scope: TableHeaderScope) -> &mut Self
pub fn scope(&mut self, scope: TableHeaderScope) -> &mut Self
Write the /Scope attribute to define whether a table header cell
refers to its row or column.
Sourcepub fn summary(&mut self, summary: impl TextStrLike) -> &mut Self
pub fn summary(&mut self, summary: impl TextStrLike) -> &mut Self
Write the /Summary attribute to set the summary of the table. PDF
1.7+.
Sourcepub fn short(&mut self, short: impl TextStrLike) -> &mut Self
pub fn short(&mut self, short: impl TextStrLike) -> &mut Self
Write the /Short attribute to set a short form of the table header’s
content. PDF 2.0+.
Methods from Deref<Target = Dict<'a>>
Sourcepub fn insert(&mut self, key: Name<'_>) -> Obj<'_>
pub fn insert(&mut self, key: Name<'_>) -> Obj<'_>
Start writing a pair with an arbitrary value.
Sourcepub fn pair<T: Primitive>(&mut self, key: Name<'_>, value: T) -> &mut Self
pub fn pair<T: Primitive>(&mut self, key: Name<'_>, value: T) -> &mut Self
Write a pair with a primitive value.
This is a shorthand for dict.insert(key).primitive(value).
Sourcepub fn pairs<'n, T: Primitive>(
&mut self,
pairs: impl IntoIterator<Item = (Name<'n>, T)>,
) -> &mut Self
pub fn pairs<'n, T: Primitive>( &mut self, pairs: impl IntoIterator<Item = (Name<'n>, T)>, ) -> &mut Self
Write a sequence of pairs with primitive values.