pub struct TrackSizes<'a> { /* private fields */ }Expand description
Writer for a column tracks attribute value. PDF 1.6+.
This writer is created by LayoutAttributes::column_widths and
LayoutAttributes::column_gap.
Implementations
Sourceimpl<'a> TrackSizes<'a>
impl<'a> TrackSizes<'a>
Sourcepub fn individual(self) -> TypedArray<'a, f32>
pub fn individual(self) -> TypedArray<'a, f32>
Start writing an array of values for individual tracks. If there are more tracks than values, the last value is used for all remaining tracks.